@@ -27,6 +27,7 @@
 #include <stdlib.h>
 #include <sys/types.h>
 #include <unistd.h>
+#include <string.h>
 #include <allegro/debug.h>
 #include <allegro/file.h>
 #include <allegro/datafile.h>
@@ -400,8 +401,8 @@ SAMPLE *alogg_create_sample(struct DATAFILE *dat)
 
   ovd->size=dat->size;
   ovd->position=0;
+  ovd->allocated=0;
   ovd->data=dat->dat;
-  ovd->pcmdata=NULL;
   sample=load_via_callbacks(ovd,&datafile_callbacks);
 
   return sample;
@@ -458,7 +459,7 @@ SAMPLE *alogg_load_ogg(AL_CONST char *filename)
 
   /* open the file as a PACKFILE */
   pf=pack_fopen(filename,"r");
-  if (!pf) {
+  if (pf) {
     sample=load_ogg_from_packfile(pf);
     pack_fclose(pf);
     return sample;
@@ -521,8 +522,8 @@ alogg_stream *alogg_start_streaming_datafile(
 
   ovd->size=dat->size;
   ovd->position=0;
+  ovd->allocated=0;
   ovd->data=dat->dat;
-  ovd->pcmdata=NULL;
   stream=alogg_start_streaming_callbacks(
     ovd,(struct ov_callbacks*)&datafile_callbacks,block_size,NULL
   );
@@ -536,7 +537,6 @@ alogg_stream *aloggint_start_streaming_datogg(
 {
   if (!ovd) return NULL;
   ovd->position=0;
-  ovd->pcmdata=NULL;
   return alogg_start_streaming_callbacks(
     ovd,(struct ov_callbacks*)&memory_callbacks,block_size,NULL
   );
@@ -626,15 +626,15 @@ int alogg_read_stream_data(alogg_stream *stream,void *block,size_t size)
   TRACE("%u bytes actually read\n",read_size);
   if (size!=read_size) {
     /* fill with silence to make sure old data doesn't get played */
-    int n;
+    size_t n;
     if (stream->audio_stream->samp->stereo) {
       unsigned short *sblock=(unsigned short*)((char*)block+read_size);
-      unsigned short value=read_size>=2?sblock[-1]:0;
+      unsigned short value=read_size>=2?sblock[-1]:0x8000;
       for (n=0;n<(size-read_size)/2;++n) sblock[n]=value;
     }
     else {
-      unsigned char *sblock=(char*)block+read_size;
-      unsigned char value=read_size>=1?sblock[-1]:0;
+      unsigned char *sblock=(unsigned char*)block+read_size;
+      unsigned char value=read_size>=1?sblock[-1]:0x80;
       for (n=0;n<size-read_size;++n) sblock[n]=value;
     }
   }
@@ -693,11 +693,15 @@ static int write_vorbis_headers(
   ogg_packet header,comments,codebooks;
   vorbis_comment vc;
   size_t n;
+  char ver[8];
 
   ASSERT(data);
 
   vorbis_comment_init(&vc);
   vorbis_comment_add_tag(&vc,"ENCODER",ALOGG_ID " Allegro Ogg/Vorbis library");
+  snprintf(ver,sizeof(ver),"%d.%d.%d",ALOGG_MAJOR,ALOGG_MINOR,ALOGG_PATCH);
+  ver[sizeof(ver)-1]=0;
+  vorbis_comment_add_tag(&vc,"ALOGG VERSION",ver);
   for (n=0;n<ncomments;++n) vorbis_comment_add(&vc,user_comments[n]);
   vorbis_analysis_headerout(&data->vd,&vc,&header,&comments,&codebooks);
   ogg_stream_packetin(&data->os,&header);
